@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------------
    libconfig - A library for processing structured configuration files
-   Copyright (C) 2005-2018  Mark A Lindner
+   Copyright (C) 2005-2025  Mark A Lindner
 
    This file is part of libconfig.
 
@@ -23,16 +23,27 @@
 #ifndef __wincompat_h
 #define __wincompat_h
 
-#include <limits.h>
 
 #if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) \
   || defined(WIN64) || defined(_WIN64) || defined(__WIN64__)
+#define LIBCONFIG_WINDOWS_OS
+#endif
+
+#if defined(__MINGW32__) || defined(__MINGW64__)
+#define LIBCONFIG_MINGW_OS
+#endif
+
+
+#include <limits.h>
+
+#ifdef LIBCONFIG_WINDOWS_OS
 
 /* Prevent warnings about redefined malloc/free in generated code. */
 #ifndef _STDLIB_H
 #define _STDLIB_H
 #endif
 
+#include <io.h>
 #include <malloc.h>
 
 #ifdef _MSC_VER
@@ -42,13 +53,19 @@
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 
-#define fileno _fileno
+#define posix_fileno _fileno
+#define posix_write  _write
+
+/* Might be able to replace this with:
+#define posix_fsync  _commit
+*/
+extern int posix_fsync(int fd);
 
 #if _MSC_VER <= 1800
 #define snprintf  _snprintf
 #endif
 
-#if !defined(__MINGW32__) && _MSC_VER < 1800
+#if !defined(LIGCONFIG_MINGW_OS) && _MSC_VER < 1800
 #define atoll     _atoi64
 #define strtoull  _strtoui64
 #define strtoll   _strtoi64
@@ -60,9 +77,11 @@
 
 #endif
 
-#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) \
-  || defined(WIN64) || defined(_WIN64) || defined(__WIN64__) \
-  || defined(__MINGW32__))
+#if defined(LIBCONFIG_WINDOWS_OS) || defined(LIBCONFIG_MINGW_OS)
+
+#ifndef STDERR_FILENO
+#define STDERR_FILENO 2
+#endif
 
 #define INT64_FMT "%I64d"
 #define UINT64_FMT "%I64u"
@@ -71,7 +90,7 @@
 
 #define FILE_SEPARATOR "\\"
 
-#else /* defined(WIN32) || defined(__MINGW32__) */
+#else /* defined(LIBCONFIG_WINDOWS_OS) || defined(LIBCONFIG_MINGW_OS) */
 
 #define INT64_FMT "%lld"
 #define UINT64_FMT "%llu"
@@ -80,30 +99,36 @@
 
 #define FILE_SEPARATOR "/"
 
-#endif /* defined(WIN32) || defined(__MINGW32__) */
+#endif /* defined(LIBCONFIG_WINDOWS_OS) || defined(LIBCONFIG_MINGW_OS) */
 
-#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) \
-  || defined(WIN64) || defined(_WIN64) || defined(__WIN64__)) \
-  && ! defined(__MINGW32__)
+#if defined(LIBCONFIG_WINDOWS_OS) && !defined(LIBCONFIG_MINGW_OS)
 
 #define INT64_CONST(I)  (I ## i64)
 #define UINT64_CONST(I) (I ## Ui64)
 
-#ifndef INT_MAX
-#define INT_MAX (2147483647)
+#ifndef INT32_MAX
+#define INT32_MAX (2147483647)
 #endif
 
-#ifndef INT_MIN
-#define INT_MIN (-2147483647-1)
+#ifndef INT32_MIN
+#define INT32_MIN (-2147483647-1)
+#endif
+
+#ifndef UINT32_MAX
+#define UINT32_MAX (4294967295U)
 #endif
 
 #include <Shlwapi.h>
 #define IS_RELATIVE_PATH(P) \
   (PathIsRelativeA(P))
 
-extern int fsync(int fd);
+#else /* defined(LIBCONFIG_WINDOWS_OS) && !defined(LIBCONFIG_MINGW_OS) */
 
-#else /* defined(WIN32/WIN64) && ! defined(__MINGW32__) */
+#include <unistd.h> /* for fsync() */
+
+#define posix_fileno fileno
+#define posix_fsync  fsync
+#define posix_write  write
 
 #define INT64_CONST(I)  (I ## LL)
 #define UINT64_CONST(I) (I ## ULL)
@@ -111,8 +136,6 @@ extern int fsync(int fd);
 #define IS_RELATIVE_PATH(P) \
   ((P)[0] != '/')
 
-#include <unistd.h> /* for fsync() */
-
-#endif /* defined(WIN32/WIN64) && ! defined(__MINGW32__) */
+#endif /* defined(LIBCONFIG_WINDOWS_OS) && !defined(LIBCONFIG_MINGW_OS) */
 
 #endif /* __wincompat_h */
